@@ -66,12 +66,12 @@
 
 /* Build against libtiff. */
 #ifndef ENABLE_LIBTIFF
-#define ENABLE_LIBTIFF 1
+/* #undef ENABLE_LIBTIFF */
 #endif
 
 /* Build against libpng. */
 #ifndef ENABLE_LIBPNG
-#define ENABLE_LIBPNG 1
+/* #undef ENABLE_LIBPNG */
 #endif
 
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
@@ -109,7 +109,7 @@
 
 /* Use header-only classes from Boost in the Splash backend */
 #ifndef USE_BOOST_HEADERS
-#define USE_BOOST_HEADERS 1
+/* #undef USE_BOOST_HEADERS */
 #endif
 
 //------------------------------------------------------------------------
